rf\_info.data package
=====================

Submodules
----------

rf\_info.data.a\_allocations module
-----------------------------------

.. automodule:: rf_info.data.a_allocations
   :members:
   :undoc-members:
   :show-inheritance:

rf\_info.data.b\_allocations module
-----------------------------------

.. automodule:: rf_info.data.b_allocations
   :members:
   :undoc-members:
   :show-inheritance:

rf\_info.data.c\_allocations module
-----------------------------------

.. automodule:: rf_info.data.c_allocations
   :members:
   :undoc-members:
   :show-inheritance:

rf\_info.data.international module
----------------------------------

.. automodule:: rf_info.data.international
   :members:
   :undoc-members:
   :show-inheritance:

rf\_info.data.rangekeydict module
---------------------------------

.. automodule:: rf_info.data.rangekeydict
   :members:
   :undoc-members:
   :show-inheritance:

rf\_info.data.satellites module
-------------------------------

.. automodule:: rf_info.data.satellites
   :members:
   :undoc-members:
   :show-inheritance:

rf\_info.data.us module
-----------------------

.. automodule:: rf_info.data.us
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: rf_info.data
   :members:
   :undoc-members:
   :show-inheritance:
